# Generated by Django 3.2.5 on 2022-12-28 17:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('nameserverapi', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Akas',
        ),
        migrations.DeleteModel(
            name='Events',
        ),
        migrations.DeleteModel(
            name='Y2016',
        ),
        migrations.DeleteModel(
            name='Y2017',
        ),
        migrations.DeleteModel(
            name='Y2018',
        ),
        migrations.DeleteModel(
            name='Y2019',
        ),
        migrations.DeleteModel(
            name='Y2020',
        ),
        migrations.DeleteModel(
            name='Y2021',
        ),
        migrations.DeleteModel(
            name='Y2022',
        ),
        migrations.DeleteModel(
            name='Y2023',
        ),
        migrations.DeleteModel(
            name='Y2024',
        ),
        migrations.DeleteModel(
            name='Y2025',
        ),
        migrations.DeleteModel(
            name='Y2026',
        ),
        migrations.DeleteModel(
            name='Y2027',
        ),
        migrations.DeleteModel(
            name='Y2028',
        ),
        migrations.DeleteModel(
            name='Y2029',
        ),
        migrations.DeleteModel(
            name='Y2030',
        ),
    ]
