sh curl_atlas3_good.sh > atlas3_good.log 2>&1
sh curl_atlas3_attic.sh > atlas3_attic.log 2>&1
sh curl_atlas3_possible.sh > atlas3_possible.log 2>&1
sh curl_atlas3_garbage.sh > atlas3_garbage.log 2>&1
sh curl_atlas4_good.sh > atlas4_good.log 2>&1
sh curl_atlas4_attic.sh > atlas4_attic.log 2>&1
sh curl_atlas4_possible.sh > atlas4_possible.log 2>&1
sh curl_atlas4_stars.sh > atlas4_stars.log 2>&1
sh curl_atlas4_garbage.sh > atlas4_garbage.log 2>&1

