curl -X POST http://127.0.0.1:8000/eventapi/ -d '{"internalObjectId": "1021813821391554700", "internalName": "ATLAS20ruf", "ra": "34.5576", "decl": "39.26523", "flagDate": "2020-06-30", "survey_database": "atlas4"}' -H 'Content-Type: application/json' -H 'Authorization: Token 5022dac0e3bda0504a77288bd7499675fafff1b5'
echo ""
